@@ -214,7 +214,7 @@ only be used by at most one repository.
 </p>
 <p>
 <em>Example</em>:
-<tt>Meta-Distributions: unstable=sid-unstable experimental=sid-experimental</tt>
+<kbd>Meta-Distributions: unstable=sid-unstable experimental=sid-experimental</kbd>
 (see standard layout 'Debian Developer'), to allow upload/testing of
 packages (to unstable,experimental,..) aimed for Debian.
 </p>
@@ -293,7 +293,7 @@ packages (to unstable,experimental,..) aimed for Debian.
                 name="Debian Developer",
                 defaults={"mandatory_version_regex": ".*",
                           "experimental_mandatory_version_regex": ".*",
-                          "extra_options": "Meta-Distributions: stable=squeeze-unstable unstable=sid-unstable experimental=sid-experimental\n"})
+                          "extra_options": "Meta-Distributions: unstable=sid-unstable experimental=sid-experimental\n"})
 
             if created:
                 debdev_unstable = SuiteOption(
@@ -535,7 +535,7 @@ pimp the internal priority up here.
 </p>
 <p>
 <em>Example</em>:
-<tt>Internal-APT-Priority: 500</tt>: Always build against newer internal packages.
+<kbd>Internal-APT-Priority: 500</kbd>: Always build against newer internal packages.
 </p>
 """,
                                "fields": ("extra_options",)}),)
@@ -1278,6 +1278,9 @@ gnupghome {h}
         # better place.
         self.mbd_package_purge_orphaned_logs(msglog=MsgLog(LOG, request))
 
+        # Check for ambiguity with other repos in meta distribution maps
+        get_meta_distribution_map()
+
     def mbd_get_dependencies(self):
         result = []
         for d in self.distributions.all():
@@ -1293,6 +1296,18 @@ def get_meta_distribution_map():
         for d in r.distributions.all():
             for s in r.layout.suiteoption_set.all():
                 for m in r.mbd_get_meta_distributions(d, s):
-                    result[m] = s.mbd_get_distribution_string(r, d)
+                    distribution = s.mbd_get_distribution_string(r, d)
+                    if m in result:
+                        raise Exception("Ambiguous Meta-Distributions ({m0}={d0} or {d1}). "
+                                        "Please check Repositories and Layouts (see Layouts/Meta-Distributions in Administrators Manual).".format(m0=m,
+                                                                                                                                                  d0=distribution,
+                                                                                                                                                  d1=result[m]))
+                    result[m] = distribution
+
     LOG.debug("Got meta distribution map: {m}".format(m=result))
     return result
+
+
+def map_incoming_distribution(incoming_dist):
+    " Map incoming distribution to internal. "
+    return get_meta_distribution_map().get(incoming_dist, incoming_dist)
